@@ -28,7 +28,7 @@ public interface File {
 	 * @return the size
 	 * @throws InternalErrorException the internal error exception
 	 */
-	public Long getSize() throws InternalErrorException;
+	public Long getSize();
 
 	/**
 	 * The folder myme type.
@@ -36,7 +36,7 @@ public interface File {
 	 * @return the myme type
 	 * @throws InternalErrorException the internal error exception
 	 */
-	public String getMimeType() throws InternalErrorException;
+	public String getMimeType();
 
 
 }
